const jsonUrl = 'https://raw.githubusercontent.com/freeCodeCamp/ProjectReferenceData/master/global-temperature.json';
const width = 1200;
const height = 450;
const margin = { top: 40, bottom: 95, left: 110, right: 60 };
const mlist = [ "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December" ];

const innerWidth = width - margin.left - margin.right;
const innerHeight = height - margin.top - margin.bottom;

d3.json(jsonUrl).then(data => {
	const baseTemp = data.baseTemperature;
  const variation = data.monthlyVariance;
  const colorScale = d3.scaleOrdinal().domain(d3.extent(variation, d=>d.year)).range(['red','blue','green','yellow']);
  const xScale = d3.scaleLinear().domain(d3.extent(variation, d => d.year)).range([0, innerWidth]);
  const yScale = d3.scaleBand().domain(variation.map(v => v.month)).range([0, innerHeight]);
 	const opScale = d3.scaleLinear().domain([0, 2*baseTemp]).range([0, 1]);
  template = `
      <div id='title'>
        <h1>Monthly Global Land-Surface Temperature</h1>
        <h2>${variation[0].year} - ${variation[variation.length-1].year}: base temperature ${baseTemp}</h2>
      </div>
      <svg width=${width} height=${height}>
      <g transform="translate(${margin.left},${margin.top})">
        
      </g>
      </svg>
      <div id='tooltip'></div>
      <div id='legend'></div>
    `;
	let node = document.getElementById('root');
  node.innerHTML = template;
  
	const svg = d3.select("svg");
	const g = svg.append("g").attr("transform", "translate(" + margin.left + "," + margin.top + ")");
  
  const xaxis = g.append("g").attr('id','x-axis').attr("transform","translate(0,"+innerHeight + ")");
  xaxis.append("line").attr("x2",innerWidth).attr("stroke","black");
  xaxis.append('text').attr('id','axis-label').attr('x',innerWidth/2).attr('text-achor','middle').attr('y',40).text('Years');
  
  const yaxis = g.append("g").attr('id','y-axis');
  yaxis.append('line').attr('y2',innerHeight).attr('stroke','black');
  yaxis.append('text').attr('id','axis-label').attr('transform','translate(-80,' + innerHeight/2 + ') rotate(-90)').attr('text-anchor','middle').text('Months');
  
	yScale.domain().map(tickValue => {
    const yticks = yaxis.append("g").attr("class","tick").attr("transform", "translate(0," + yScale(tickValue) + ")")
  	yticks.append("text").attr("text-anchor", "end").attr("dy","0.32em").attr('x',-5).text(mlist[tickValue-1]);
    yticks.append('line').attr('x1',-5).attr('stroke','black');
  });
	
  xScale.ticks().map(tickValue => {
    const xticks = xaxis.append("g").attr("class","tick").attr("transform", "translate(" + xScale(tickValue) + ",5)")
  	xticks.append('line').attr('y1',-5).attr('stroke','black');
    xticks.append("text").attr("text-anchor", "middle").attr("dy","0.71em").text(tickValue);
  });
  
  variation.map(d => { 
              const bars = g.append('g').attr('class','bars').attr('transform','translate(' + xScale(d.year) + ',' + yScale(d.month) + ')').on('mouseenter', () => {
              	d3.select('#tooltip').append('span').text(d.year + ' - ' + mlist[d.month-1]);
                              		d3.select('#tooltip').append('span').text(baseTemp + d.variance + '°C');
                              		d3.select('#tooltip').append('span').text(d.variance + '°C');
                              		d3.select('#tooltip').style('left', xScale(d.year) + margin.left + 'px');
																  d3.select('#tooltip').style('top', yScale(d.month)  + margin.top + 'px'); 
                              		d3.select('#tooltip').style('visibility','visible');
              }).on('mouseleave', () => {
              	d3.select('#tooltip').selectAll('span').remove();
                        d3.select('#tooltip').style('visibility','hidden');
              });
    					bars.append('rect').attr('fill',colorScale(d.year)).attr('fill-opacity',opScale(baseTemp + d.variance)).attr('height',yScale.bandwidth()).attr('width', innerWidth / (variation[variation.length-1].year - variation[0].year));
  });
  
})